@@ -11,6 +11,7 @@
 /*      Configuration of the serial port                               */
 /*                                                                     */
 /*   ChangeLog                                                         */
+/*      - 0.99.5 : Make the combo list for the device editable         */
 /*      - 0.99.3 : Configuration for VTE terminal                      */
 /*      - 0.99.2 : Internationalization                                */
 /*      - 0.99.1 : fixed memory management bug                         */
@@ -191,10 +192,10 @@ gint Config_Port_Fenetre(GtkWidget *widget, guint param)
   gtk_table_attach(GTK_TABLE(Table), Label, 2, 3, 0, 1, 0, 0, 10, 5);
 
   Combo = gtk_combo_new();
-  gtk_editable_set_editable(GTK_EDITABLE((GTK_COMBO(Combo)->entry)), FALSE);
+  gtk_editable_set_editable(GTK_EDITABLE((GTK_COMBO(Combo)->entry)), TRUE);
 
   gtk_combo_set_popdown_strings(GTK_COMBO(Combo), liste);
-  gtk_combo_set_value_in_list(GTK_COMBO(Combo), TRUE, FALSE);
+  gtk_combo_set_value_in_list(GTK_COMBO(Combo), FALSE, FALSE);
   chaine = g_strdup(config.port);
   if(g_list_find_custom(liste, chaine, (GCompareFunc)strcmp) != NULL)
     gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(Combo)->entry), chaine);
