@@ -13,6 +13,13 @@
 /*   ChangeLog                                                         */
 /*   (All changes by Julien Schmitt except when explicitly written)    */
 /*                                                                     */
+/*      - 0.99.5 : Make package buildable on pure *BSD by changing the */
+/*                 include to asm/termios.h by sys/ttycom.h            */
+/*                 Print message without converting it into the locale */
+/*                 in show_message()                                   */
+/*                 Set backspace key binding to backspace so that the  */
+/*                 backspace works. It would even be nicer if the      */
+/*                 behaviour of this key could be configured !         */
 /*      - 0.99.4 : - Sebastien Bacher -                                */
 /*                 Added functions for CR LF auto mode                 */
 /*                 Fixed put_text() to have \r\n for the VTE Widget    */
@@ -42,7 +49,14 @@
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
-#include <asm/termios.h>       /* For control signals */
+#if defined (__linux__)
+#  include <asm/termios.h>       /* For control signals */
+#endif
+#if defined (__FreeBSD__) || defined (__FreeBSD_kernel__) \
+     || defined (__NetBSD__) || defined (__NetBSD_kernel__) \
+     || defined (__OpenBSD__) || defined (__OpenBSD_kernel__) 
+#  include <sys/ttycom.h>        /* For control signals */
+#endif
 #include <vte/vte.h>
 #include <stdio.h>
 #include <string.h>
@@ -282,6 +296,9 @@ void create_main_window(void)
 
   display = vte_terminal_new();
 
+  vte_terminal_set_backspace_binding(VTE_TERMINAL(display),
+				     VTE_ERASE_ASCII_BACKSPACE);
+
   clear_display();
 
   gtk_box_pack_start_defaults(GTK_BOX(BoiteH), display);
@@ -565,12 +582,12 @@ void show_message(gchar *message, gint type_msg)
  if(type_msg==MSG_ERR)
    {
      Fenetre_msg = 
-       gtk_message_dialog_new(GTK_WINDOW(Fenetre), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, g_locale_to_utf8(message, -1, NULL, NULL, NULL));
+       gtk_message_dialog_new(GTK_WINDOW(Fenetre), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, message);
    }
  else if(type_msg==MSG_WRN)
    {
      Fenetre_msg = 
-       gtk_message_dialog_new(GTK_WINDOW(Fenetre), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, g_locale_to_utf8(message, -1, NULL, NULL, NULL));
+       gtk_message_dialog_new(GTK_WINDOW(Fenetre), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, message);
    }
  else
    return;
